@@ -12,7 +12,7 @@
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
-   version 3 of the License, or (at your option) any later version.
+   version 2 of the License, or (at your option) any later version.
    
    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -173,8 +173,8 @@
 #import	<Foundation/NSObject.h>
 
 #if OS_API_VERSION(GS_API_MACOSX, GS_API_LATEST)
-#import	<Foundation/NSUtilities.h>
 #import	<Foundation/NSDictionary.h>
+#import	<Foundation/NSEnumerator.h>
 
 #if	defined(__cplusplus)
 extern "C" {
@@ -186,7 +186,7 @@ extern "C" {
 @class NSDate;
 @class NSArray;
 @class NSMutableArray;
-
+@class NSEnumerator;
 @class NSDirectoryEnumerator;
 
 @interface NSFileManager : NSObject
